;; Generated package description from cond-star.el  -*- mode: lisp-data; no-byte-compile: t -*-
(define-package "cond-star" "1.0.0.20250310.74521" "Extended form of `cond' construct" '((emacs "24.3")) :commit "4980089960ab467ad00fb2b3369b26f477cb0186" :url "https://elpa.gnu.org/packages/cond-star.html" :maintainer '("Richard Stallman" . "rms@gnu.org"))
